@@ -1,4 +1,4 @@
-#' Read Peptide Identificationa and Quantitation Data-Files (peptidess.txt) Produced By MaxQuant
+#' Read Peptide Identification and Quantitation Data-Files (peptides.txt) Produced By MaxQuant
 #'
 #' Peptide level identification and quantification data produced by \href{https://www.maxquant.org/}{MaxQuant} can be read using
 #' this function and relevant information extracted.
@@ -41,7 +41,7 @@
 #' @param contamCol (character or integer, length=1) which columns should be used for contaminants
 #' @param pepCountCol (character) pattern to search among column-names for count data (defaults to 'Experiment')
 #' @param sampleNames (character) custom column-names for quantification data; this argument has priority over \code{suplAnnotFile}
-#' @param extrColNames (character) column names to be read (1st position: prefix for LFQ quantitation, default 'LFQ.intensity';
+#' @param extrColNames (character) column names to be read (1st position: prefix for quantitation, default 'intensity';
 #'   2nd: column name for peptide-IDs, default )
 #' @param specPref (character) prefix to identifiers allowing to separate i) recognize contamination database,
 #'   ii) species of main identifications and iii) spike-in species
@@ -52,9 +52,11 @@
 #'   for initial/raw abundance values and \code{$quant} with final normalized quantitations
 #' @param gr (character or factor) custom defined pattern of replicate association, will override final grouping of
 #'   replicates from \code{sdrf} and/or \code{suplAnnotFile} (if provided)   \code{}
-#' @param sdrf (character, list or data.frame) optional extraction and adding of experimenal meta-data: if character,
-#'   this may be the ID at ProteomeExchange. Besides, the output from \code{readSdrf} or a list from \code{defineSamples} may be provided;
-#'   if \code{gr} is provided, it gets priority for grouping of replicates
+#' @param sdrf (character, list or data.frame) optional extraction and adding of experimenal meta-data: if character, this may be the ID at ProteomeExchange,
+#'   the second & third elements may give futher indicatations for automatic organization of groups of replicates.
+#'   Besides, the output from \code{readSdrf} or a list from \code{defineSamples} may be provided;
+#'   if \code{gr} is provided, \code{gr} gets priority for grouping of replicates;
+#'   if \code{sdrfOrder=TRUE} the output will be put in order of sdrf
 #' @param suplAnnotFile (logical or character) optional reading of supplemental files produced by MaxQuant; if \code{gr} is provided, it gets priority for grouping of replicates
 #'   if \code{TRUE} default to files 'summary.txt' (needed to match information of \code{sdrf}) and 'parameters.txt' which can be found in the same folder as the main quantitation results;
 #'   if \code{character} the respective file-names (relative ro absolute path), 1st is expected to correspond to 'summary.txt' (tabulated text, the samples as given to MaxQuant) and 2nd to 'parameters.txt' (tabulated text, all parameters given to MaxQuant)
@@ -78,7 +80,7 @@
 #'   tit="Tiny MaxQuant Peptides")
 #' summary(dataMQpep$quant)
 #' @export
-readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="median", quantCol="LFQ.intensity", contamCol="Potential.contaminant",
+readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="median", quantCol="Intensity", contamCol="Potential.contaminant",
   pepCountCol="Experiment", refLi=NULL,  sampleNames=NULL,
   extrColNames=c("Sequence","Proteins","Leading.razor.protein","Start.position","End.position","Mass","Missed.cleavages","Unique..Groups.","Unique..Proteins.","Charges"),
   specPref=c(conta="conta|CON_|LYSC_CHICK", mainSpecies="HUMAN"),
@@ -113,7 +115,7 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
 
   ## initial read MaxQuant
   tmp <- try(utils::read.delim(file.path(path,fileName), stringsAsFactors=FALSE), silent=TRUE)
-  if(debug) {message(fxNa,"rMQP2"); rMQP2 <- list(path=path,chPa=chPa,tmp=tmp,contamCol=contamCol,extrColNames=extrColNames,remConta=remConta)}
+  if(debug) {message(fxNa,"rMQP2"); rMQP2 <- list()}
 
   if(length(tmp) <1 | inherits(tmp, "try-error")) {
     message(fxNa,"Unable to read file 'fileName' !  Returning NULL; check if this is original MaxQuant-file and/or rights to read")
@@ -132,35 +134,45 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
       if(any(!chCol, na.rm=TRUE) ) {
         if(!silent) message(fxNa,"Note: Can't find columns ",wrMisc::pasteC(extrColNames[!chCol], quoteC="'")," !")
       }
-      if(debug) {message(fxNa,"rMQP3")}
+      if(debug) {message(fxNa,"rMQP3"); rMQP3 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,remConta=remConta,quantCol=quantCol)}
 
       ## 'REVERSE' peptides
       chRazProCol <- extrColNames[3] %in% colnames(tmp)
       chRev <- grep("REV__", tmp[,extrColNames[if(chRazProCol) 3 else 2]])
-        if(debug) message(fxNa,"rMQP3b    chRev : ",utils::head(chRev),"\n")
+        if(debug) message(fxNa,"rMQP3b    chRev : ",utils::head(paste(chRev, collapse=" ")),"\n")
       if(length(chRev) >0) {
         if(!silent) message(fxNa,"Note: Found ",length(chRev)," out of ",nrow(tmp)," peptides with proteins marked as 'REV_' (reverse peptide identification)", if(isTRUE(remRev)) " - Removing")
         if(isTRUE(remRev)) tmp <- if(length(chRev) < nrow(tmp) -1)  tmp[-1*chRev,] else matrix(tmp[-1*chRev,], nrow=nrow(tmp)-length(remRev), dimnames=list(rownames(tmp)[-1*chRev], colnames(tmp)))
       }
       ## remove MaxQuant internal contaminants CON__
-      if(isTRUE(remConta) & nrow(tmp) >0) { isConta <- grep("CON__{0,1}[[:alpha:]]+", tmp[,extrColNames[2]])
+      if(isTRUE(remConta) && nrow(tmp) >0) { isConta <- grep("CON__{0,1}[[:alpha:]]+", tmp[,extrColNames[2]])
         if(length(isConta) >0) {
           if(!silent) message(fxNa,"Note: Found ",length(isConta)," out of ",nrow(tmp)," proteins marked as 'CON_' (contaminants) - Removing")
           tmp <- if(length(isConta) < nrow(tmp) -1) tmp[-1*isConta,] else matrix(tmp[-1*isConta,], nrow=nrow(tmp)-length(isConta), dimnames=list(rownames(tmp)[-1*isConta], colnames(tmp)))
         } }
       } else if(!silent) message(fxNa,"BIZZARE, trouble ahead : Unable to find columns ",wrMisc::pasteC(extrColNames[2:3],quoteC="'")," (from argument 'extrColNames')")
-    if(debug) {message(fxNa,"rMQP4"); rMQP4 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRazProCol=chRazProCol,chRev=chRev,remConta=remConta)}
+    if(debug) {message(fxNa,"rMQP4"); rMQP4 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRazProCol=chRazProCol,chRev=chRev,remConta=remConta,quantCol=quantCol,pepCountCol=pepCountCol)}
   }
   if(length(tmp) >0) {
     ## further extracting : quantitation
     grepX <- function(x) grep(paste0(x,"\\."), colnames(tmp))
     useDCol <- if(length(quantCol)==1) grepX(quantCol) else unique(as.integer(sapply(quantCol, grepX)))
-    if(length(useDCol) <1) warning(fxNa, "NO columns matching terms ",wrMisc::pasteC(quantCol, quoteC="'")," from argument 'quantCol' found !") else {
+    if(length(useDCol) <1) { useDCol <- if(length(quantCol)==1) grepX(tolower(quantCol)) else unique(as.integer(sapply(tolower(quantCol), grepX)))
+      if(length(useDCol) >0) {  # need to re-adjust 'quantCol'
+        ch1 <- regexpr(tolower(quantCol), tolower(colnames(tmp)[useDCol])) 
+        quantCol <- unique(substr(colnames(tmp)[useDCol], ch1, ch1+ nchar(quantCol)-1) )
+        if(length(quantCol) >1) {if(!silent) message(fxNa,"Need to adjust 'quantCol' , but found ",length(quantCol)," variants, using '",quantCol[1],"' ")}
+      } 
+    }
+   if(debug) {message(fxNa,"rMQP4a"); rMQP4a <- list()}
+    if(length(useDCol) <1) { abund <- NULL
+      warning(fxNa, "NO columns matching terms ",wrMisc::pasteC(quantCol, quoteC="'")," from argument 'quantCol' found !  rMQP4a")
+    } else {
       quantColP <- NULL                           # initialize
       if(length(quantCol) <1) stop(" 'quantCol' must be provided !")
       if(length(quantCol) >1) { abund <- as.matrix(wrMisc::extrColsDeX(tmp, extrCol=quantCol, doExtractCols=TRUE, silent=silent, callFrom=fxNa))
       } else { chP <- substr(quantCol, nchar(quantCol), nchar(quantCol)) != "."
-        quantColP <- quantCol
+        #quantColP <- quantCol
         quantCol <- if(chP) grep(paste0(quantCol,"\\."), colnames(tmp)) else grep(quantCol, colnames(tmp))
         chNa <- is.na(quantCol)
         if(all(chNa) | length(quantCol) <1) stop("Could not find any of the columns specified in argument 'quantCol' !")
@@ -168,10 +180,11 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
           if(!silent) message(fxNa,"Could not find columns ",wrMisc::pasteC(quantCol[which(chNa)],quote="'")," .. omit")
           quantCol <- wrMisc::naOmit(quantCol)}
         abund <- as.matrix(tmp[,quantCol]) }           # abundance val
+        if(debug) {message(fxNa,"rMQP4b"); rMQP4b <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRazProCol=chRazProCol,chRev=chRev,remConta=remConta,quantCol=quantCol,pepCountCol=pepCountCol)}
       chNum <- is.numeric(abund)
       if(!chNum) {abund <- apply(tmp[,quantCol], 2, wrMisc::convToNum, convert="allChar", silent=silent, callFrom=fxNa)}
       if(length(dim(abund)) <2) abund <- matrix(as.numeric(abund), ncol=ncol(abund), dimnames=dimnames(abund))
-      colnames(abund) <- if(length(quantColP)==1) sub(paste0(quantColP,"\\."),"", colnames(abund)) else wrMisc::.trimFromStart(wrMisc::.trimFromEnd(colnames(abund)))
+      colnames(abund) <- if(length(quantColP)==1) sub(paste0(quantColP,"\\."),"", colnames(abund)) else wrMisc::.trimLeft(wrMisc::.trimRight(colnames(abund)))
       if(debug) {message(fxNa,"rMQP5")}
 
       ## convert 0 to NA
@@ -194,7 +207,7 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     ch2 <- sapply(usePCol, length)  -ncol(abund)                # take abund as ref for not extracting more cols
     if(any(ch2 >0, na.rm=TRUE)) usePCol[which(ch2 >0)] <- lapply(usePCol[which(ch2 >0)], function(x) x[-1])
     ch2 <- sapply(usePCol, length) ==ncol(abund)      # update
-    if(!silent & any(!ch2, na.rm=TRUE)) message(fxNa,"Could not find peptide counts columns (argument 'pepCountCol') matching to '",pepCountCol[which(!ch2)],"'")
+    if(!silent && any(!ch2, na.rm=TRUE)) message(fxNa,"Could not find peptide counts columns (argument 'pepCountCol') matching to '",pepCountCol[which(!ch2)],"'")
     if(debug) {message(fxNa,"rMQP6"); rMQP6 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRazProCol=chRazProCol,chRev=chRev,quantCol=quantCol,abund=abund,chNum=chNum,ch2=ch2,usePCol=usePCol,pepCountCol=pepCountCol,specPref=specPref,remConta=remConta)}
     ## make array of PSM counts etc
     if(any(ch2, na.rm=TRUE)) {
@@ -209,7 +222,7 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     specMQ <- rep(NA, nrow(abund))         # initialize
     if(debug) {message(fxNa,"rMQP6b")}
 
-    useProCo <- 2+ extrColNames[3] %in% colnames(tmp)         # specific to eptide reading
+    useProCo <- 2 + extrColNames[3] %in% colnames(tmp)         # specific to eptide reading
     .MultGrep <- function(pat, y) if(length(pat)==1) grep(pat, y) else unlist(sapply(pat, grep, y))  # (multiple) grep() when length of pattern 'pat' >0
 
     ## MaxQuant internal contaminants specific : remove non-protein DB parts - if possible, eg "CON__ENSEMBL:ENSBTAP00000007350;CON__P01030" -> "CON__P01030"
@@ -256,14 +269,18 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
         #specMQ0 <- specMQ0[-conLi]
         counts <- if(length(dim(counts))==3) counts[-conLi,,] else counts[-conLi,,]
         if(debug) message(fxNa,"Removing ",length(conLi)," instances of MaxQuant-contaminants to final ",nrow(MQann)," lines/IDs")} }
-    if(debug) {message(fxNa,"rMQP7b")}
+    if(debug) {message(fxNa,"rMQP7b"); rMQP7b <- list()}
 
     ## split Annotation
     remHeader <- c("^conta\\|","^sp\\|")
-    MQan2 <- strsplit(sub(remHeader[1], "", sub(remHeader[2], "", if(useProCo==2) sub(";.+", "", MQann[,useProCo+1]) else MQann[,useProCo+1])), "\\|")
+    MQan2 <- strsplit(sub(remHeader[1], "", sub(remHeader[2], "", if(useProCo==2) sub(";.+", "", MQann[,useProCo+1]) else MQann[,useProCo+1])), "\\|") # separate AccessionNumber (eg P02768) and EntryName (eg ALBU_HUMAN)       
     MQan2 <- t(sapply(MQan2, function(x) if(length(x)==1) { c(NA,x)} else x[1:2]) )
     colnames(MQan2) <- c("Accession","EntryName")
-    MQan2 <- cbind(MQan2, Species=sub("_.+|[[:punct:]].+","", sub("[[:upper:]]+[[:digit:]]*_", "", MQan2[,2]))) # separate AccessionNumber (eg P02768) and EntryName (eg ALBU_HUMAN)
+    MQan2 <- cbind(MQan2, Species=NA)
+    hasSpe <- grep("._", MQan2[,2])
+    if(length(hasSpe) >0) MQan2[hasSpe,3] <- gsub(".*_", "", MQan2[hasSpe,2])       # separate 'YEAST' from "MTNA_YEAST 
+    #gsub(".*_", "", MQan2[,2]))   # separate AccessionNumber (eg P02768) and EntryName (eg ALBU_HUMAN)
+    #MQan2 <- cbind(MQan2, Species=sub("_.+|[[:punct:]].+","", sub("[[:upper:]]+[[:digit:]]*_", "", MQan2[,2]))) # separate AccessionNumber (eg P02768) and EntryName (eg ALBU_HUMAN)
 
     ## extract species according to custom search parameters 'specPref'
     .annSpecies <- function(spe=c("_HUMAN","Homo sapiens"), anno=MQann, exCoNa=extrColNames) {
@@ -274,10 +291,11 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     if(remStrainNo) {
       commonSpec <- .commonSpecies()
       commonSpec[,1] <- sub("^_","", commonSpec[,1])   # '_' has already been stripped off during strsplit
-      for(i in 1:nrow(commonSpec)) MQan2[,"Species"] <- sub(commonSpec[i,1], commonSpec[i,2], MQan2[,"Species"]) }
+      convSpe <- which(commonSpec[,1] %in% unique(MQan2[hasSpe,"Species"]))
+      if(length(convSpe) >0) for(i in convSpe) MQan2[hasSpe,"Species"] <- sub(commonSpec[i,1], commonSpec[i,2], MQan2[hasSpe,"Species"]) }
 
     MQann <- cbind(MQann, MQan2)
-    if(debug) { message(fxNa,"rMQP7c")}
+    if(debug) { message(fxNa,"rMQP7c"); rMQP7c <- list(path=path,chPa=chPa,tmp=tmp,abund=abund,MQan2=MQan2,MQann=MQann,remStrainNo=remStrainNo,remConta=remConta,extrColNames=extrColNames,remHeader=remHeader)}
 
     ## contaminants (fuse from column 'Potential.contaminant' and those found via specPref[1])
     contam <- rep(FALSE, nrow(MQann))
@@ -286,7 +304,7 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
       if(any(chCo, na.rm=TRUE)) contam[which(chCo)[1]] <- TRUE
       MQann[,"Potential.contaminant"] <- contam
     } else MQann <- cbind(MQann,Potential.contaminant=contam)
-    if(debug) {message(fxNa,"rMQP9")}
+    if(debug) {message(fxNa,"rMQP9");  rMQP9 <- list()}
 
     ## look for unique col from $annot to use as rownames
     rowNa <- MQann[,2]
@@ -303,6 +321,8 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     }
     rownames(abund) <- rownames(MQann) <- rowNa
     if(length(counts) >0) rownames(counts) <- rownames(MQann)
+    if(debug) {message(fxNa,"rMQP9b");  rMQP9b <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRazProCol=chRazProCol,counts=counts,contam=contam,
+      rowNa=rowNa,refLi=refLi,chRev=chRev,quantCol=quantCol,abund=abund,chNum=chNum,ch2=ch2,MQann=MQann,specMQ=specMQ,remConta=remConta)}
 
     ## check for reference for normalization
     refLiIni <- refLi
@@ -315,22 +335,61 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     quant <- try(wrMisc::normalizeThis(log2(abund), method=normalizeMeth, mode="additive", refLines=refLi, silent=silent, debug=debug, callFrom=fxNa), silent=TRUE)
     if(inherits(quant, "try-error")) { warning(fxNa,"PROBLEMS ahead : Unable to normalize as log2-data !!") }
 
-    if(debug) {message(fxNa,"rMQP10"); rMQP10 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,chCol=chCol,chRev=chRev,quantCol=quantCol,abund=abund,chNum=chNum,ch2=ch2,
+    if(debug) {message(fxNa,"rMQP10"); rMQP10 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,groupPref=groupPref,chCol=chCol,chRev=chRev,quantCol=quantCol,abund=abund,chNum=chNum,ch2=ch2,
       quant=quant,MQann=MQann,MQan2=MQan2,contam=contam,remConta=remConta)}
 
     ### GROUPING OF REPLICATES AND SAMPLE META-DATA
     if(length(suplAnnotFile) >0 || length(sdrf) >0) {
+      if(length(sampleNames) %in% c(1, ncol(abund))) groupPref$sampleNames <- sampleNames
+      if(length(gr) %in% c(1, ncol(abund))) groupPref$gr <- gr
+      if(debug) {message(fxNa,"rMQP11"); rMQP11 <- list()}
       setupSd <- readSampleMetaData(sdrf=sdrf, suplAnnotFile=suplAnnotFile, quantMeth="MQ", path=path, abund=utils::head(quant), groupPref=groupPref, silent=silent, debug=debug, callFrom=fxNa)
     }
-    if(debug) {message(fxNa,"rMQP13 .."); rMQP13 <- list()}
+    if(debug) {message(fxNa,"rMQP13 .."); rMQP13 <- list(path=path,chPa=chPa,tmp=tmp,extrColNames=extrColNames,groupPref=groupPref,chCol=chCol,chRev=chRev,quantCol=quantCol,abund=abund,chNum=chNum,ch2=ch2,
+      quant=quant,MQann=MQann,MQan2=MQan2,contam=contam,remConta=remConta,setupSd=setupSd)}
 
     ## finish groups of replicates & annotation setupSd
     setupSd <- .checkSetupGroups(abund=abund, setupSd=setupSd, gr=gr, sampleNames=sampleNames, quantMeth="MQ", silent=silent, debug=debug, callFrom=fxNa)
-    colNa <- if(length(setupSd$sampleNames)==ncol(abund)) setupSd$sampleNames else setupSd$groups
-    chGr <- grepl("^X[[:digit:]]", colNa)                                                # check & remove heading 'X' from initial column-names starting with digits
-    if(any(chGr)) colNa[which(chGr)] <- sub("^X","", colNa[which(chGr)])                 # 
-    colnames(quant) <- colnames(abund) <- colNa
-    if(length(setupSd$sampleNames)==ncol(abund)) setupSd$sampleNames <- colNa else setupSd$groups <- colNa
+
+    ## option : set order of samples as sdrf
+    if("sdrfOrder" %in% names(sdrf) && isTRUE(as.logical(sdrf["sdrfOrder"])) && length(setupSd$iniSdrfOrder)==ncol(abund) && ncol(abund) >1) {  # set order according to sdrf (only if >1 samples)
+      nOrd <- order(setupSd$iniSdrfOrder)
+      ## rename columns according to sdrf and set order of quant and abund ..
+      abund <- abund[,nOrd]
+      if(length(quant) >0) quant <- quant[,nOrd]
+      if(length(setupSd$sampleNames)==ncol(quant)) {
+        colNa <- colnames(abund) <- setupSd$sampleNames <- setupSd$sampleNaSdrf[nOrd]  #old# setupSd$sampleNames[nOrd]         ## take sample names from sdrf via  setupSd$sampleNaSdrf
+        if(length(quant) >0) colnames(quant) <- setupSd$sampleNaSdrf[nOrd]  #old# setupSd$sampleNames[nOrd]
+      } else colNa <- colnames(abund)
+      ## now adapt order of setupSd, incl init Sdrf
+      if(length(setupSd) >0) { 
+        is2dim <- sapply(setupSd, function(x,le) length(dim(x))==2 && nrow(x)==le, le=length(nOrd))    # look for matr or df to change order of lines
+        if(any(is2dim) >0) for(i in which(is2dim)) setupSd[[i]] <- setupSd[[i]][nOrd,]
+        isVe <- sapply(setupSd, function(x,le) length(x)==le && length(dim(x)) <1, le=length(nOrd))    # look for vector to change order in setupSd
+        if(any(isVe) >0) for(i in which(isVe)) setupSd[[i]] <- setupSd[[i]][nOrd] }
+      gr <- gr[nOrd]
+
+      if(length(counts) >0 && length(dim(counts))==3) counts <- array(counts[,nOrd,], dim=c(nrow(counts), length(nOrd), dim(counts)[3]), 
+        dimnames=list(rownames(counts), colnames(counts)[nOrd], dimnames(counts)[[3]]))
+      ## try re-adjusting levels
+      tm1 <- sub("^[[:alpha:]]+( |_|-|\\.)+[[:alpha:]]+","", colnames(abund))  # remove heading text
+      if(all(grepl("^[[:digit:]]", tm1))) {
+        tm1 <- try(as.numeric(sub("( |_|-|\\.)*[[:alpha:]].*","", tm1)), silent=TRUE)   # remove tailing text and try converting to numeric
+        if(!inherits(tm1, "try-error")) {
+          setupSd$level <- match(tm1, sort(unique(tm1)))
+          names(setupSd$level) <- tm1
+          if(!silent) message(fxNa,"Sucessfully re-adjusted levels after bringing in order of Sdrf")}
+      }     
+    } else {
+
+      ## harmonize sample-names/2
+      colNa <- colnames(abund)
+      chGr <- grepl("^X[[:digit:]]", colNa)                                                # check & remove heading 'X' from initial column-names starting with digits
+      if(any(chGr)) colNa[which(chGr)] <- sub("^X","", colNa[which(chGr)])                 #
+      colnames(quant) <- colNa
+      if(length(abund) >0) colnames(abund) <- colNa  
+    }  
+    if(length(setupSd$sampleNames)==ncol(abund)) setupSd$sampleNames <- colNa #no#else setupSd$groups <- colNa
     if(length(dim(counts)) >1 && length(counts) >0) colnames(counts) <- colNa
 
     if(debug) {message(fxNa,"Read sample-meta data, rMQP14"); rMQP14 <- list(sdrf=sdrf,suplAnnotFile=suplAnnotFile,abund=abund, quant=quant,refLi=refLi,MQann=MQann,setupSd=setupSd)}
@@ -350,4 +409,5 @@ readMaxQuantPeptides <- function(path, fileName="peptides.txt", normalizeMeth="m
     ## prepare for final output
     if(isTRUE(separateAnnot)) list(raw=abund, quant=quant, annot=MQann, counts=counts, sampleSetup=setupSd, quantNotes=parametersD, notes=notes) else data.frame(abund, MQann) }
 }
-  
+   
+                                                                                                       
\ No newline at end of file
